Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrIncorrectRepositoryURL = errors.New("Git repository could not be found, please ensure that the URL is correct.") ErrAuthenticationFailure = errors.New("Authentication failed, please ensure that the git credentials are correct.") )
Functions ¶
This section is empty.
Types ¶
type GitAuthentication ¶
type RepoConfig ¶
type RepoConfig struct {
// The repo url
URL string `example:"https://github.com/portainer/portainer.git"`
// The reference name
ReferenceName string `example:"refs/heads/branch_name"`
// Path to where the config file is in this url/refName
ConfigFilePath string `example:"docker-compose.yml"`
// Git credentials
Authentication *GitAuthentication
// Repository hash
ConfigHash string `example:"bc4c183d756879ea4d173315338110b31004b8e0"`
}
RepoConfig represents a configuration for a repo
Click to show internal directories.
Click to hide internal directories.